ODSPlus - Recent Opinions

# Recent Decisions

Please click on the case number to view the decision. Items are ordered by case type (CR, CV, etc.) and decision filed date (in descending order.) Opinions filed after August 2002 are listed with a summary of significant issues involved in the case.
Criminal
2 CA-CR 2013-0296 | STATE OF ARIZONA v. CARLOS UBALDO GONZALEZ | Opinion Filed: 07/15/2014
Did a police officer conduct an investigatory stop by parking his marked patrol car behind a parked vehicle, blocking its exit, when the occupants of the vehicle did not appear to notice or react to the officer’s presence?
2 CA-CR 2013-0096 | STATE OF ARIZONA v. AGUSTIN GONZALEZ GONGORA | Opinion Filed: 06/23/2014
Under the voyeurism statute, A.R.S. § 13-1424, can a person’s privacy be invaded when the person is in a public place and reasonably expects to be viewed by the public, but the defendant views the person in a manner that captures the person’s genitalia, buttock or female breast, whether clothed or unclothed, that is not otherwise visible to the public, such as an “upskirt” viewing?
2 CA-CR 2013-0194 | STATE OF ARIZONA v. VINCENT MICHAEL ALLEN | Opinion Filed: 06/04/2014
Did sufficient evidence support the defendant’s conviction for forgery when the facts established the defendant used a false name when he signed a written warning for trespassing issued by a police officer? Did the trial court commit fundamental, prejudicial error by pronouncing sentence in the defendant’s absence after finding the defendant had voluntarily absented himself by walking out of the courtroom during his sentencing hearing?
2 CA-CR 2013-0065 | STATE OF ARIZONA v. ESGARDO JAVIER NEVAREZ | Opinion Filed: 05/30/2014
Did the trial court err in denying the defendant’s motion to suppress evidence based on a police stop of the defendant’s vehicle for lack of a license plate when the officer failed to see a properly displayed temporary license until he had approached the vehicle on foot, at which point he observed evidence of driving under the influence? Did police violate the defendant’s right to counsel by denying his request for an attorney to read to him a warrant they had obtained to draw his blood?
2 CA-SA 2005-0080 | ROUBOS v. CITY OF TUCSON | Opinion Filed: 04/28/2006
Is a party who successfully defends against a city’s civil infraction action alleging the party violated a city ordinance entitled to attorney fees pursuant to A.R.S. § 12-348?
2 CA-SA 2005-0085 | CALLAN, MIRANDA, AZUELO... v. PIMBER | Opinion Filed: 03/22/2006
1. Did the trial court err in denying summary judgment in favor of the City of Tucson and individual police defendants on the plaintiff police officer’s lawsuit for injuries sustained during a joint police operation? 2. Does the Workers’ Compensation Act and an intergovernmental agreement between the police agencies involved divest the superior court of jurisdiction over the plaintiffs’ negligence and willful misconduct action? 3. What effect does the failure by the parties to the intergovernmental agreement to post the notice required by A.R.S. § 23-1022(E) of the Workers’ Compensation Act have on the viability of the lawsuit?
2 CA-SA 2005-0102 | FRED MILLER M.D., et ux. v. LUZ BARRERA, MUTUAL INSURANCE CO | Opinion Filed: 01/30/2006
Did the trial court abuse its discretion by compelling the defendant in a wrongful death action based on medical malpractice to disclose the amounts paid in settlement of previous medical malpractice actions brought against the defendant?
2 CA-SA 2005-0072 | NIKONT v. STATE OF ARIZONA | Opinion Filed: 11/02/2005
Is a defendant who has been granted a resentencing because of a violation of the holding in Blakely v. Washington, 542 U.S. 296, 124 S. Ct. 2531 (2004), entitled to a change of judge as a matter of right under Rule 10.2, Ariz. R. Crim. P.?
2 CA-SA 2005-0011 | STATE OF ARIZONA v. JONATHAN McMULLEN | Opinion Filed: 06/22/2005
1. By waiving generally his right to a jury trial pursuant to a plea agreement, did the defendant waive his right to a jury trial established in Blakely v. Washington on the alleged aggravating circumstances for sentencing purposes? 2. Were the defendant’s statements, made at the change-of-plea hearing to establish a factual basis for the plea but pertaining to matters beyond what was necessary to establish the elements of reckless manslaughter, admissions for purposes of Blakely? And by making those statements, did the defendant waive the right to have a jury determine the facts underlying the alleged aggravating circumstances?
2 CA-SA 2005-0018 | STATE OF ARIZONA v. SEYMOUR JAMEEL ABDULLAH | Opinion Filed: 05/25/2005
In a prosecution for possession of a deadly weapon by a prohibited possessor under A.R.S. § 13-3102(A)(4), who bears the burden, under A.R.S. § 13-3101(A)(6)(b), of proving whether the defendant’s right to possess or carry a gun or firearm has or has not been restored?
2 CA-SA 2005-0001 | RENEE ANTONIO FRAGOSO v. THE STATE OF ARIZONA | Opinion Filed: 05/10/2005
Does a trial court’s imposition of “cash-only” bail as a condition of a defendant’s pretrial release violate Arizona’s pertinent criminal rules or statute, Rules 7.1 and 7.3, Ariz. R. Crim. P.; A.R.S. § 13-3967; or the constitutional right to bail “by sufficient sureties,” Ariz. Const. art. II, § 22(A)?
2 CA-SA 2004-0057 | STATE OF ARIZONA v. HON. HOWARD FELL; EDWARD JOHN SANDERS | Opinion Filed: 09/23/2004
1. Is A.R.S. § 13-703.01(Q) retroactively applicable to a non-capital murder defendant whose offense was committed before the effective date of the statute? 2. Does the United States Supreme Court’s decision in Blakely v. Washington apply to a non-capital first-degree murder case, entitling the defendant to have a jury find the existence of aggravating factors beyond a reasonable doubt before the defendant may be sentenced to a prison term of natural life, rather than life with the possibility of parole?
2 CA-SA 2004-0017 | DARREN CLAY MEDDERS v. THE STATE OF ARIZONA | Opinion Filed: 06/04/2004
SA 2004-0017 Issue Statement Does a criminal defendant who appears at a contested hearing before a judge who hears that matter only but is not assigned to the case waive the right to a peremptory change of judge, pursuant to Rule 10.2, Ariz. R. Crim. P., 16A A.R.S., when the case is later reassigned to that judge for trial?
2 CA-SA 2003-0107 - 2 CA-SA 2003-0108 (consolidated) | CHARTONE, INC. v. MERCALDO, LTD.; WEBB, PC.; DURAZZO & ECKEL; SMART PROFESSIONAL | Opinion Filed: 02/06/2004
1. Absent an agreement by the parties, do article VI, § 24 of the Arizona Constitution and Rule 53, Ariz. R. Civ. P., 16 A.R.S., Pt. 1, authorize a trial judge to appoint a special master to calculate the plaintiffs’ damages after a jury had found the defendants liable? 2. Did the trial court violate the defendants’ rights to a jury trial by vacating the damages phase of a bifurcated trial and appointing a special master to calculate the plaintiffs’ damages?
2 CA-SA 2003-0101 | THE STATE OF ARIZONA v. AMY LOU HENDERSON | Opinion Filed: 12/23/2003
Do A.R.S. § 28-1383(D) and Rule 7.2(b)(1), Ariz. R. Crim. P., require immediate incarceration of a defendant upon a jury’s verdict of guilt on aggravated DUI?
2 CA-SA 2003-0067 | TANQUE VERDE UNIFIED SCHOOL DISTRICT NO. 13 OF PIMA COUNTY v. TANQUE VERDE COALITION, INC., et. al. | Opinion Filed: 09/23/2003
1. Did the school district board violate the open meeting laws by conducting a site selection process in executive session? 2. Did the board timely ratify its vote selecting a site on which to build a new school at a meeting held within thirty days after the trial judge ruled the board had violated the open meeting laws but more than a year after its original vote? 3. May school districts use School Facilities Board funds to pay severance damages in eminent domain actions to condemn sites on which to build new schools?
2 CA-SA 2003-0053 - 2 CA-SA 2003-0054,2 CA-SA 2003-0055,2 CA-SA 2003-0060 (consolidated) | JENNIFER L. BERGERON v. HON. COLIN CAMPBELL | Opinion Filed: 08/21/2003
When a party seeks a change of judge as a matter of right pursuant to Rule 10.2, Ariz. R. Crim. P., 16A A.R.S., may that judge or any other judge conduct an inquiry to determine whether the party has sought the change for an improper purpose, or must the case be assigned to a different judge upon compliance with the rule?
2 CA-SA 2003-0026 | STATE v. HANTMAN; RIEDEL | Opinion Filed: 04/01/2003
When misdemeanor criminal charges are filed, dismissed without prejudice, and refiled within the limitations period, then dismissed without prejudice again after the limitations period has expired, may the state refile the charges within six months of the second dismissal pursuant to A.R.S. § 13-107(G)?
2 CA-SA 2003-0008 - 2 CA-SA 2003-0015 (consolidated) | JEREMY SEAN O'BRIEN v. THE STATE OF ARIZONA | Opinion Filed: 03/24/2003
1. Does A.R.S. § 13-901.01(E), as amended by Proposition 302 in November 2002, apply retroactively to Proposition 200 probationers who committed offenses before the amended statute took effect? 2. Does the holding in State v. Estrada, 201 Ariz. 247, 34 P.3d 356 (2001), that Proposition 200 applies to drug paraphernalia offenses, apply to persons who committed offenses before Estrada was decided?
2 CA-SA 2002-0107 | ALTHAUS V. PENN-AMERICA INS. CO. | Opinion Filed: 12/12/2002
Does the “final judgment accrual rule” apply in determining the date the statute of limitations period begins in a legal malpractice action when the underlying case was settled?
2 CA-SA 2002-0046 | QWEST CORPORATION V. MARK MCMAHON | Opinion Filed: 10/24/2002
ISSUES: What is the scope of the exclusive jurisdiction of the Corporation Commission and are claims for consumer fraud and negligent misrepresentation, brought in superior court, barred under the “filed rate doctrine?”
2 CA-SA 2002-0067 | STATE OF ARIZONA v. AMIEL PROTO | Opinion Filed: 10/10/2002
ISSUE: Does the Victims’ Bill of Rights, Ariz. Const. art. II, § 2.1, entitle alleged victims of a defendant in an unrelated prosecution to decline to be interviewed by the defense in connection with that prosecution?

Continue to decisions page.